@@ -68,10 +68,11 @@ MainWindow::MainWindow(QWidget *parent, const Session& session) : KXmlGuiWindow(
     setupActions();
     setupGUI(ToolBar | Keys | Save | Create, QStringLiteral("kronometerui.rc"));
 
-    // TODO: find a better fix for #351746
-    resize(minimumSizeHint());
+    // #351746: prevent ugly 640x480 default size (unless there is a previous size to be restored, see #361494).
+    if (not isWindowSizeSaved()) {
+        resize(minimumSizeHint());
+    }
 
-    slotInactive();    // inactive state is the default
     loadSettings();
     statusBar()->hide();
 
@@ -79,7 +80,7 @@ MainWindow::MainWindow(QWidget *parent, const Session& session) : KXmlGuiWindow(
         loadSession();
     }
     else {
-        setWindowTitle(i18nc("untitled window", "Untitled"));
+        slotInactive();
     }
 
     // TODO: replace this whit solid-power API, once it's released.
@@ -173,7 +174,7 @@ void MainWindow::slotInactive()
 {
     m_startAction->setText(i18nc("@action", "&Start"));
 
-    m_session.setIsOutdated(false);
+    m_session = Session {};
 
     setWindowTitle(i18nc("untitled window", "Untitled"));
     setWindowModified(false);
@@ -227,7 +228,6 @@ void MainWindow::slotWriteSettings()
 
 void MainWindow::slotUpdateLapDock()
 {
-    m_lapView->resizeColumnsToContents();
     m_lapView->horizontalHeader()->setStretchLastSection(true);
     m_lapView->selectRow(m_lapModel->rowCount({}) - 1);  // rows indexes start from 0
 }
@@ -240,7 +240,7 @@ void MainWindow::slotNewSession()
 
 void MainWindow::slotOpenSession()
 {
-    QPointer<SessionDialog> dialog = new SessionDialog {nullptr, i18nc("@title:window", "Open Session")};
+    QPointer<SessionDialog> dialog = new SessionDialog {this, i18nc("@title:window", "Open Session")};
 
     if (dialog.data()->exec() == QDialog::Accepted) {
         auto window = new MainWindow {nullptr, dialog.data()->selectedSession()};
@@ -640,6 +640,20 @@ void MainWindow::exportLapsAsCsv(QTextStream& out)
     }
 }
 
+bool MainWindow::isWindowSizeSaved() const
+{
+    KConfigGroup group {KSharedConfig::openConfig(), "MainWindow"};
+
+    foreach (const auto& key, group.keyList()) {
+        // Size keys contain the screen size, e.g. 'Width 1920' and 'Height 1080'.
+        if (key.startsWith(QLatin1String("Height")) or key.startsWith(QLatin1String("Width"))) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 QString MainWindow::timestampMessage()
 {
     const auto timestamp = QDateTime::currentDateTime();
